# hydroplane  
A Data Exploration Custom Dashboard Framework  


## Quick Start  
```python
from hydroplane import Hydroplane  

# START HYDROPLANE
hp = Hydroplane("HYDROPLANE", 8053) 
hp.start_up() 
``` 

## To Do  
[ ] Hydroplane Onboarding Tutorial / Minimum Requirements  
[ ] Kubernetes Templates  
[ ] Docker Image Repository AWS  
[ ] 